@@ -16,17 +16,17 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
+#include <xapian.h>
+
 #include "contactcompleter.h"
 #include "query.h"
-#include <xapian.h>
 
 #include <QStandardPaths>
 #include <QDebug>
-
 #include <QFile>
 
 using namespace Akonadi::Search::PIM;
@@ -74,11 +74,20 @@ QStringList ContactCompleter::complete()
     QStringList list;
     Xapian::MSetIterator end = mset.end();
     list.reserve(mset.size());
-    for (; mit != end; ++mit) {
-        std::string str = mit.get_document().get_data();
-        const QString entry = QString::fromUtf8(str.c_str(), str.length());
-        list << entry;
+    Q_FOREVER {
+        try {
+            for (; mit != end; ++mit) {
+                std::string str = mit.get_document().get_data();
+                const QString entry = QString::fromUtf8(str.c_str(), str.length());
+                list << entry;
+            }
+            return list;
+        } catch (const Xapian::DatabaseCorruptError &e) {
+            qWarning() << "The emailContacts Xapian database is corrupted:" << QString::fromStdString(e.get_description());
+            return QStringList();
+        } catch (const Xapian::DatabaseModifiedError &e) {
+            db.reopen();
+            continue; // try again
+        }
     }
-
-    return list;
 }
