@@ -16,7 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -49,7 +49,7 @@ int main(int argc, char **argv)
     for (int i = 0; i < size; i++) {
         QByteArray term = QUuid::createUuid().toByteArray().mid(1, 10);
 
-        if (parser.isSet(QLatin1String("p"))) {
+        if (parser.isSet(QStringLiteral("p"))) {
             std::string stdString(term.constData(), term.length());
             doc.doc().add_posting(stdString, i);
         } else {
@@ -58,7 +58,7 @@ int main(int argc, char **argv)
     }
 
     qDebug() << "Added" << size << "terms";
-    if (parser.isSet(QLatin1String("p"))) {
+    if (parser.isSet(QStringLiteral("p"))) {
         qDebug() << "With Positional Information";
     }
     return app.exec();
